@@ -1,4 +1,4 @@
-library(markovchain)
+#library(markovchain)
 require(diagram)
 require(DiagrammeR)
 # P <- matrix(c(0, 0.5, 0.5,
